#
# spec file for package perl-ExtUtils-CChecker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name ExtUtils-CChecker
Name:           perl-ExtUtils-CChecker
Version:        0.120.0
Release:        1.4
# 0.12 -> normalize -> 0.120.0
%define cpan_version 0.12
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Configure-time utilities for using C headers,
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PE/PEVANS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(Module::Build) >= 0.4004
BuildRequires:  perl(Test2::V0)
Requires:       perl(ExtUtils::CBuilder)
Provides:       perl(ExtUtils::CChecker) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Often Perl modules are written to wrap functionality found in existing C
headers, libraries, or to use OS-specific features. It is useful in the
_Build.PL_ or _Makefile.PL_ file to check for the existance of these
requirements before attempting to actually build the module.

Objects in this class provide an extension around ExtUtils::CBuilder to
simplify the creation of a _.c_ file, compiling, linking and running it, to
test if a certain feature is present.

It may also be necessary to search for the correct library to link against,
or for the right include directories to find header files in. This class
also provides assistance here.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Tue Mar  5 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.12
  see /usr/share/doc/packages/perl-ExtUtils-CChecker/Changes
  0.12    2024-03-02
    [CHANGES]
  * Document the `->define` method
  * Overall module style updates
    + `use v5.14` in all files
    + use `package NAME VER` syntax
    + Use `Test2::V0` instead of `Test::More` + `Test::Fatal`
* Tue Jul 13 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.11
  see /usr/share/doc/packages/perl-ExtUtils-CChecker/Changes
  0.11    2021-07-12
    [CHANGES]
  * Added `try_find_cflags_for`
  * Added `extend_module_build`
  * Various small style fixes
* Sun Jun  7 2015 coolo@suse.com
- updated to 0.10
  see /usr/share/doc/packages/perl-ExtUtils-CChecker/Changes
  0.10    2015/05/29 19:14:24
    [CHANGES]
  * Added 'config' passthrough constructor argument for EU:CB (RT95368)
* Mon Feb 24 2014 coolo@suse.com
- updated to 0.09
  * Add a 'quiet' option so EU:CB's quiet can be disabled (RT91363)
  * Fixed some typoes in docs
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.08
  * Include PID in test file names to guard against collisions when
    building concurrently (RT76013)
* Mon Dec 19 2011 coolo@suse.de
- update to 0.07:
  * Use Test::Fatal instead of Test::Exception
  * Advise against calling it "config.h" as that gets confused with
    core perl's file
* Sun Feb  6 2011 lars@linux-schulserver.de
- update to 0.06:
  + Added 'defines_to' constructor arg for writing a "config.h" file
    instead of -DFOO on compiler commandline
  + Added accessors for callers to push more library dirs or compiler
    or linker flags
  + Ensure that ->new_module_build merges its args and internal
    configuration correctly
- BuildRequire Test::Pod for testing the pod files
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul 13 2010 chris@computersalat.de
- update to 0.04
  * Provide optional variants of ->find_include_dirs_for and
  - >find_libs_for with try_... prefix
- recreated by cpanspec 1.78
- noarch pkg
* Tue May 11 2010 cwh@novell.com
- initial release in OBS
